@@ -5,7 +5,7 @@ from collections import OrderedDict
 from itertools import groupby
 import numpy as np
 from ..helper import AtomType, ResidueType, Xopen, Xdict, set_real_global_variable, set_attribute_alternative_names, \
-    set_global_alternative_names, Guess_Element_From_Mass
+    set_global_alternative_names, Guess_Element_From_Mass, Xprint
 
 
 class AssignRule:
@@ -253,12 +253,12 @@ class Assign():
 
     def add_index_to_name(self):
         """
-        This **function** adds the atom index to the atom name
+        This **function** renames the atoms by adding the index to the element name
 
         :return: None
         """
         for i in range(self.atom_numbers):
-            self.names[i] += str(i)
+            self.names[i] = self.atoms[i] + str(i)
 
     def atom_judge(self, atom, string):
         """
@@ -498,8 +498,11 @@ instance yourself, remember to determine the ring and bond type!
                                         a2=parameters.get("a2", 0.001), two_stage=parameters.get("two_stage", True),
                                         only_esp=parameters.get("only_esp", False),
                                         radius=parameters.get("radius", None))
+        elif method == "GASTEIGER":
+            from . import gasteiger
+            self.charge = gasteiger.Gasteiger(self)
         else:
-            raise ValueError("methods should be one of the following: 'RESP'")
+            raise ValueError("methods should be one of the following: 'RESP', 'GASTEIGER'")
 
     def save_as_pdb(self, filename):
         """
